@@ -6,10 +6,9 @@ test_that(desc="test connections to apis in catalogue",{
   
   skip_on_cran()
   
-  apis <- names(api_parameters())
+#  apis <- names(api_parameters())
   
-  for(api in apis){
-    expect_true(suppressMessages(pxweb_api$new(api)$test_api()))
-  }
-
+#  for(api in apis){
+#    expect_true(suppressMessages(pxweb_api$new(api)$test_api()))
+#  }
 })
